Index: src/sas/sasgui/perspectives/fitting/basepage.py
===================================================================
--- src/sas/sasgui/perspectives/fitting/basepage.py	(revision 9e0aa69abc3080680008f6c3525d79d3fb3ba4e9)
+++ src/sas/sasgui/perspectives/fitting/basepage.py	(revision e92a35222de59b469e74be44064685ec4edc7c19)
@@ -55,5 +55,5 @@
 class BasicPage(ScrolledPanel, PanelBase):
     """
-    This class provide general structure of  fitpanel page
+    This class provide general structure of the fitpanel page
     """
     # Internal name for the AUI manager
@@ -677,7 +677,7 @@
     def _copy_info(self, flag):
         """
-        Send event dpemding on flag
-
-        : Param flag: flag that distinguish event
+        Send event depending on flag
+
+        : Param flag: flag that distinguishes the event
         """
         # messages depending on the flag
@@ -1119,5 +1119,5 @@
         :precondition: the page is already drawn or created
 
-        :postcondition: the state of the underlying data change as well as the
+        :postcondition: the state of the underlying data changes as well as the
             state of the graphic interface
         """
@@ -1335,5 +1335,5 @@
     def _selectDlg(self):
         """
-        open a dialog file to selected the customized dispersity
+        open a dialog file to select the customized polydispersity function
         """
         if self.parent is not None:
@@ -1760,5 +1760,5 @@
     def _set_multfactor_combobox(self, multiplicity=10):
         """
-        Set comboBox for muitfactor of CoreMultiShellModel
+        Set comboBox for multitfactor of CoreMultiShellModel
         :param multiplicit: no. of multi-functionality
         """
@@ -1798,5 +1798,5 @@
         Fill panel's combo box according to the type of model selected
         """
-        custom_model = 'Customized Models'
+        custom_model = 'Plugin Models'
         mod_cat = self.categorybox.GetStringSelection()
         self.structurebox.SetSelection(0)
@@ -3453,5 +3453,5 @@
         fills out the category list box
         """
-        uncat_str = 'Customized Models'
+        uncat_str = 'Plugin Models'
         self._read_category_info()
 
@@ -3482,5 +3482,5 @@
         self.model_box.Clear()
 
-        if category == 'Customized Models':
+        if category == 'Plugin Models':
             for model in self.model_list_box[category]:
                 str_m = str(model).split(".")[0]
Index: src/sas/sasgui/perspectives/fitting/models.py
===================================================================
--- src/sas/sasgui/perspectives/fitting/models.py	(revision 0de74afcaf1a275ffd2e71099f9e17e398dcc39a)
+++ src/sas/sasgui/perspectives/fitting/models.py	(revision e92a35222de59b469e74be44064685ec4edc7c19)
@@ -325,5 +325,5 @@
                     self.plugins.append(plug)
                     self.model_dictionary[name] = plug
-            self.model_combobox.set_list("Customized Models", self.plugins)
+            self.model_combobox.set_list("Plugin Models", self.plugins)
             return self.model_combobox.get_list()
         else:
@@ -346,5 +346,5 @@
             self.model_dictionary[name] = plug
 
-        self.model_combobox.reset_list("Customized Models", self.plugins)
+        self.model_combobox.reset_list("Plugin Models", self.plugins)
         return self.model_combobox.get_list()
 
@@ -389,5 +389,5 @@
 #                                     self.shape_indep_list)
         self.model_combobox.set_list("Structure Factors", self.struct_list)
-        self.model_combobox.set_list("Customized Models", self.plugins)
+        self.model_combobox.set_list("Plugin Models", self.plugins)
         self.model_combobox.set_list("P(Q)*S(Q)", self.multiplication_factor)
         self.model_combobox.set_list("multiplication",

Index: src/sas/sasgui/perspectives/fitting/fitting.py
===================================================================
--- src/sas/sasgui/perspectives/fitting/fitting.py	(revision 73cbeec4f3f2dfd3c530e5782984529dc2c133b2)
+++ src/sas/sasgui/perspectives/fitting/fitting.py	(revision e92a35222de59b469e74be44064685ec4edc7c19)
@@ -225,7 +225,6 @@
 
         self.id_edit = wx.NewId()
-        editmodel_help = "Edit customized model sample file"
         self.menu1.AppendMenu(self.id_edit, "Plugin Model Operations",
-                              self.edit_model_menu, editmodel_help)
+                              self.edit_model_menu)
         #create  menubar items
         return [(self.menu1, self.sub_menu)]
@@ -260,6 +259,6 @@
             self.update_custom_combo()
             if os.path.isfile(p_path):
-                msg = "Sorry! Could not be able to delete the default "
-                msg += "custom model... \n"
+                msg = "Sorry! unable to delete the default "
+                msg += "plugin model... \n"
                 msg += "Please manually remove the files (.py, .pyc) "
                 msg += "in the 'plugin_models' folder \n"
@@ -274,5 +273,5 @@
                     if item.GetLabel() == label:
                         self.edit_menu.DeleteItem(item)
-                        msg = "The custom model, %s, has been deleted." % label
+                        msg = "The plugin model, %s, has been deleted." % label
                         evt = StatusEvent(status=msg, type='stop', info='info')
                         wx.PostEvent(self.parent, evt)
@@ -331,5 +330,5 @@
             temp = self.fit_panel.reset_pmodel_list()
             if temp:
                 # Set the new custom model list for all fit pages
                 for uid, page in self.fit_panel.opened_pages.iteritems():
                     if hasattr(page, "formfactorbox"):
@@ -331,5 +330,5 @@
             temp = self.fit_panel.reset_pmodel_list()
             if temp:
-                # Set the new custom model list for all fit pages
+                # Set the new plugin model list for all fit pages
                 for uid, page in self.fit_panel.opened_pages.iteritems():
                     if hasattr(page, "formfactorbox"):